@@ -591,6 +591,9 @@ class Gmail(object):
 
         """
         
+        if not message_refs:
+            return []
+
         if not parallel:
             return [self._build_message_from_ref(user_id, ref, attachments)
                     for ref in message_refs]
@@ -801,9 +804,10 @@ class Gmail(object):
 
         elif payload['mimeType'].startswith('multipart'):
             ret = []
-            for part in payload['parts']:
-                ret.extend(self._evaluate_message_payload(part, user_id, msg_id,
-                                                          attachments))
+            if 'parts' in payload:
+                for part in payload['parts']:
+                    ret.extend(self._evaluate_message_payload(part, user_id, msg_id,
+                                                              attachments))
             return ret
 
         return []
